pub struct SupervisingRouteController { /* private fields */ }Expand description
A route controller that automatically restarts crashed routes.
Wraps a DefaultRouteController and spawns a supervision loop that
receives crash notifications and restarts routes with exponential backoff.
Implementations
Sourceimpl SupervisingRouteController
impl SupervisingRouteController
Sourcepub fn new(registry: Arc<Mutex<Registry>>, config: SupervisionConfig) -> Self
pub fn new(registry: Arc<Mutex<Registry>>, config: SupervisionConfig) -> Self
Create a new supervising controller.
Sourcepub fn with_languages(
registry: Arc<Mutex<Registry>>,
config: SupervisionConfig,
languages: SharedLanguageRegistry,
) -> Self
pub fn with_languages( registry: Arc<Mutex<Registry>>, config: SupervisionConfig, languages: SharedLanguageRegistry, ) -> Self
Create a new supervising controller with shared language registry.
Sourcepub fn with_metrics(self, metrics: Arc<dyn MetricsCollector>) -> Self
pub fn with_metrics(self, metrics: Arc<dyn MetricsCollector>) -> Self
Set a metrics collector for the supervision loop.